# frozen_string_literal: true
require_relative "credentials/version"

module Credentials
  class Error < StandardError; end
  NESTING_DELIMINATOR = '.'

  class << self

    def get(*args)
      keys = get_key_array(args)
      get_value keys
    end

    def all
      secrets
    end

    private

      def get_value(key_ary)
        secrets.dig(*key_ary)
      end

      def secrets
        # TODO: This should be swappable and configurable.
        Rails.application.credentials[environment.to_sym] || Rails.application.credentials
      end

      def environment
        Rails.env || ENV['RAILS_ENV'] || 'development'
      end

      def get_key_array(args)
        args.map do |arg|
          case arg
          when String
            arg.split(NESTING_DELIMINATOR)
          when Array
            arg
          when Symbol
            [arg.to_s]
          end.map(&:to_sym)
        end.flatten
      end

  end # class << self
end
